@@ -1,18 +1,19 @@
 #[macro_use(u32_bytes, bytes_u32)]
 extern crate dhcp4r;
 
-use std::net::{UdpSocket, Ipv4Addr};
-use std::time::{Duration, Instant};
 use std::collections::HashMap;
+use std::net::{Ipv4Addr, UdpSocket};
 use std::ops::Add;
+use std::time::{Duration, Instant};
 
-use dhcp4r::{packet, options, server};
+use dhcp4r::{options, packet, server};
 
 // Server configuration
 const SERVER_IP: Ipv4Addr = Ipv4Addr::new(192, 168, 0, 76);
 const IP_START: [u8; 4] = [192, 168, 0, 180];
 const SUBNET_MASK: Ipv4Addr = Ipv4Addr::new(255, 255, 255, 0);
-const DNS_IPS: [Ipv4Addr; 2] = [ // Google DNS servers
+const DNS_IPS: [Ipv4Addr; 2] = [
+    // Google DNS servers
     Ipv4Addr::new(8, 8, 8, 8),
     Ipv4Addr::new(4, 4, 4, 4),
 ];
@@ -43,38 +44,37 @@ struct MyServer {
 }
 
 impl server::Handler for MyServer {
-    fn handle_request(&mut self,
-                      server: &server::Server,
-                      in_packet: packet::Packet) {
+    fn handle_request(&mut self, server: &server::Server, in_packet: packet::Packet) {
         match in_packet.message_type() {
             Ok(options::MessageType::Discover) => {
                 // Prefer client's choice if available
-                if let Some(options::DhcpOption::RequestedIpAddress(addr)) = in_packet.option(options::REQUESTED_IP_ADDRESS) {
+                if let Some(options::DhcpOption::RequestedIpAddress(addr)) =
+                    in_packet.option(options::REQUESTED_IP_ADDRESS)
+                {
                     let addr = *addr;
                     if self.available(&in_packet.chaddr, &addr) {
-                        reply(server,
-                              options::MessageType::Offer,
-                              in_packet,
-                              &addr);
+                        reply(server, options::MessageType::Offer, in_packet, &addr);
                         return;
                     }
                 }
                 // Otherwise prefer existing (including expired if available)
                 if let Some(ip) = self.current_lease(&in_packet.chaddr) {
-                    reply(server,
-                          options::MessageType::Offer,
-                          in_packet,
-                          &ip);
+                    reply(server, options::MessageType::Offer, in_packet, &ip);
                     return;
                 }
                 // Otherwise choose a free ip if available
                 for _ in 0..LEASE_NUM {
                     self.last_lease = (self.last_lease + 1) % LEASE_NUM;
-                    if self.available(&in_packet.chaddr, &((IP_START_NUM + &self.last_lease).into())) {
-                        reply(server,
-                              options::MessageType::Offer,
-                              in_packet,
-                              &((IP_START_NUM + &self.last_lease).into()));
+                    if self.available(
+                        &in_packet.chaddr,
+                        &((IP_START_NUM + &self.last_lease).into()),
+                    ) {
+                        reply(
+                            server,
+                            options::MessageType::Offer,
+                            in_packet,
+                            &((IP_START_NUM + &self.last_lease).into()),
+                        );
                         break;
                     }
                 }
@@ -93,13 +93,14 @@ impl server::Handler for MyServer {
                     nak(server, in_packet, "Requested IP not available");
                     return;
                 }
-                self.leases.insert(req_ip,
-                                   (in_packet.chaddr, Instant::now().add(self.lease_duration)));
+                self.leases.insert(
+                    req_ip,
+                    (in_packet.chaddr, Instant::now().add(self.lease_duration)),
+                );
                 reply(server, options::MessageType::Ack, in_packet, &req_ip);
             }
 
-            Ok(options::MessageType::Release) |
-            Ok(options::MessageType::Decline) => {
+            Ok(options::MessageType::Release) | Ok(options::MessageType::Decline) => {
                 // Ignore requests to alternative DHCP server
                 if !server.for_this_server(&in_packet) {
                     return;
@@ -118,8 +119,9 @@ impl server::Handler for MyServer {
 impl MyServer {
     fn available(&self, chaddr: &[u8; 6], addr: &Ipv4Addr) -> bool {
         let pos: u32 = (*addr).into();
-        pos >= IP_START_NUM && pos < IP_START_NUM + LEASE_NUM &&
-            match self.leases.get(addr) {
+        pos >= IP_START_NUM
+            && pos < IP_START_NUM + LEASE_NUM
+            && match self.leases.get(addr) {
                 Some(x) => x.0 == *chaddr || Instant::now().gt(&x.1),
                 None => true,
             }
@@ -135,10 +137,12 @@ impl MyServer {
     }
 }
 
-fn reply(s: &server::Server,
-         msg_type: options::MessageType,
-         req_packet: packet::Packet,
-         offer_ip: &Ipv4Addr) {
+fn reply(
+    s: &server::Server,
+    msg_type: options::MessageType,
+    req_packet: packet::Packet,
+    offer_ip: &Ipv4Addr,
+) {
     let _ = s.reply(
         msg_type,
         vec![
@@ -148,7 +152,8 @@ fn reply(s: &server::Server,
             options::DhcpOption::DomainNameServer(DNS_IPS.to_vec()),
         ],
         *offer_ip,
-        req_packet);
+        req_packet,
+    );
 }
 
 fn nak(s: &server::Server, req_packet: packet::Packet, message: &str) {
@@ -156,6 +161,6 @@ fn nak(s: &server::Server, req_packet: packet::Packet, message: &str) {
         options::MessageType::Nak,
         vec![options::DhcpOption::Message(message.to_string())],
         Ipv4Addr::new(0, 0, 0, 0),
-        req_packet
+        req_packet,
     );
 }
